Learn R Programming

mldr (version 0.2.82)

[.mldr: Filter rows in amldr returning a new mldr

Description

Generates a new mldr object containing the selected rows from an existent mldr

Usage

## S3 method for class 'mldr':
[(mldrObject, rowFilter = T)

Arguments

mldrObject
Original mldr object from which some rows are going to be selected
rowFilter
Expression to filter the rows

Value

  • A new mldr object with the selected rows

See Also

mldr_from_dataframe, ==.mldr, +.mldr

Examples

Run this code
library(mldr)

highlycoupled <- genbase[.SCUMBLE > 0.05] # Select instances with highly imbalanced coupled labels
summary(highlycoupled)   # Compare the selected instances
summary(genbase)         # with the traits of the original MLD

Run the code above in your browser using DataLab