This function implements the REMEDIAL algorithm. It is a preprocessing algorithm for imbalanced multilabel datasets,
whose aim is to decouple frequent and rare classes appearing in the same instance. For doing so, it aggregates new instances to the dataset
and edit the labels present in them.
Usage
remedial(mld)
Arguments
mld
mldr object with the multilabel dataset to preprocess
Value
An mldr object containing the preprocessed multilabel dataset
F. Charte, A. J. Rivera, M. J. del Jesus, F. Herrera. "Resampling Multilabel Datasets by Decoupling Highly Imbalanced Labels". Proc. 2015 International Conference on Hybrid Artificial Intelligent Systems (HAIS 2015), pp. 489-501, Bilbao, Spain, 2015