Rdocumentation
powered by
Learn R Programming
mldr (version 0.3.22)
==.mldr: Checks if two mldr objects have the same structure
Description
Checks if two mldr objects have the same structure
Usage
"=="(mldr1, mldr2)
Arguments
mldr1
First
mldr
object to compare
mldr2
Second
mldr
object to compare
Value
TRUE
if the two mldr objects have the same structure,
FALSE
otherwise