Learn R Programming

mldr (version 0.2.82)

==.mldr: Checks if two mldr objects have the same structure

Description

Checks if two mldr objects have the same structure

Usage

## S3 method for class 'mldr':
==(mldr1, mldr2)

Arguments

mldr1
First mldr object to compare
mldr2
Second mldr object to compare

Value

  • TRUE if the two mldr objects have the same structure, FALSE otherwise